pub struct ADVZScheme(Advz<Bn254, Sha256>);Expand description
Newtype wrapper for a VID scheme type that impls
[VidScheme], [PayloadProver], [Precomputable].
Tuple Fields
0: Advz<Bn254, Sha256>Trait Implementations
Sourceimpl Clone for ADVZScheme
impl Clone for ADVZScheme
Sourcefn clone(&self) -> ADVZScheme
fn clone(&self) -> ADVZScheme
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PayloadProver<LargeRangeProofType> for ADVZScheme
impl PayloadProver<LargeRangeProofType> for ADVZScheme
Sourcefn payload_proof<B>(
&self,
payload: B,
range: Range<usize>,
) -> VidResult<LargeRangeProofType>
fn payload_proof<B>( &self, payload: B, range: Range<usize>, ) -> VidResult<LargeRangeProofType>
Compute a proof for a subslice of payload data. Read more
Sourcefn payload_verify(
&self,
stmt: Statement<'_, Self>,
proof: &LargeRangeProofType,
) -> VidResult<Result<(), ()>>
fn payload_verify( &self, stmt: Statement<'_, Self>, proof: &LargeRangeProofType, ) -> VidResult<Result<(), ()>>
Verify a proof made by [
PayloadProver::payload_proof]. Read moreSourceimpl PayloadProver<SmallRangeProofType> for ADVZScheme
impl PayloadProver<SmallRangeProofType> for ADVZScheme
Sourcefn payload_proof<B>(
&self,
payload: B,
range: Range<usize>,
) -> VidResult<SmallRangeProofType>
fn payload_proof<B>( &self, payload: B, range: Range<usize>, ) -> VidResult<SmallRangeProofType>
Compute a proof for a subslice of payload data. Read more
Sourcefn payload_verify(
&self,
stmt: Statement<'_, Self>,
proof: &SmallRangeProofType,
) -> VidResult<Result<(), ()>>
fn payload_verify( &self, stmt: Statement<'_, Self>, proof: &SmallRangeProofType, ) -> VidResult<Result<(), ()>>
Verify a proof made by [
PayloadProver::payload_proof]. Read moreSourceimpl VidScheme for ADVZScheme
impl VidScheme for ADVZScheme
Sourcetype Commit = <AdvzInternal<Bn<Config>, CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>>, ()> as VidScheme>::Commit
type Commit = <AdvzInternal<Bn<Config>, CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>>, ()> as VidScheme>::Commit
Payload commitment.
Share-specific data sent to a storage node.
Sourcetype Common = <AdvzInternal<Bn<Config>, CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>>, ()> as VidScheme>::Common
type Common = <AdvzInternal<Bn<Config>, CoreWrapper<CtVariableCoreWrapper<Sha256VarCore, UInt<UInt<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B0>, B0>, B0>, B0>, OidSha256>>, ()> as VidScheme>::Common
Common data sent to all storage nodes.
Sourcefn commit_only<B>(&mut self, payload: B) -> VidResult<Self::Commit>
fn commit_only<B>(&mut self, payload: B) -> VidResult<Self::Commit>
Compute a payload commitment
Sourcefn disperse<B>(&mut self, payload: B) -> VidResult<VidDisperse<Self>>
fn disperse<B>(&mut self, payload: B) -> VidResult<VidDisperse<Self>>
Compute shares to send to the storage nodes
Verify a share. Used by both storage node and retrieval client.
Why is return type a nested
Result? See https://sled.rs/errors
Returns: Read moreSourcefn recover_payload(
&self,
shares: &[Self::Share],
common: &Self::Common,
) -> VidResult<Vec<u8>>
fn recover_payload( &self, shares: &[Self::Share], common: &Self::Common, ) -> VidResult<Vec<u8>>
Recover payload from shares.
Do not verify shares or check recovered payload against anything.
Sourcefn is_consistent(commit: &Self::Commit, common: &Self::Common) -> VidResult<()>
fn is_consistent(commit: &Self::Commit, common: &Self::Common) -> VidResult<()>
Sourcefn get_payload_byte_len(common: &Self::Common) -> u32
fn get_payload_byte_len(common: &Self::Common) -> u32
Extract the payload byte length data from a [
VidScheme::Common].Sourcefn get_num_storage_nodes(common: &Self::Common) -> u32
fn get_num_storage_nodes(common: &Self::Common) -> u32
Extract the number of storage nodes from a [
VidScheme::Common].Sourcefn get_multiplicity(common: &Self::Common) -> u32
fn get_multiplicity(common: &Self::Common) -> u32
Extract the number of poly evals per share [
VidScheme::Common].Auto Trait Implementations
impl Freeze for ADVZScheme
impl RefUnwindSafe for ADVZScheme
impl Send for ADVZScheme
impl Sync for ADVZScheme
impl Unpin for ADVZScheme
impl UnsafeUnpin for ADVZScheme
impl UnwindSafe for ADVZScheme